@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.060_01';
+our $VERSION = '1.060_03';
 
 use Encode qw( encode );
 
@@ -31,9 +31,6 @@ sub print_sql {
     my $table = $sql->{table};
     my $str = '';
     for my $sql_type ( @$sql_typeS ) {
-        if ( $sql_type eq 'Drop_table' ) { #
-            $str .= "DROP TABLE $table\n";
-        }
         if ( $sql_type eq 'Create_table' ) { #
             my @cols = defined $sql->{create_table_cols} ? @{$sql->{create_table_cols}} : @{$sql->{insert_into_cols}};
             $str .= "CREATE TABLE $table (";
@@ -110,15 +107,6 @@ sub print_sql {
 }
 
 
-#sub dequote {
-#    my ( $sf, $str ) = @_;
-#    my $q = $sf->{i}{quote_char}; #
-#    $str =~ s/(?!>$q)$q(?!$q)//g;
-#    $str =~ s/$q$q/$q/g;
-#    return $str;
-#}
-
-
 sub quote_table {
     my ( $sf, $dbh, $td ) = @_;
     my @idx = $sf->{o}{G}{qualified_table_name} ? ( 0 .. 2 ) : ( 2 );
@@ -154,7 +142,7 @@ sub print_error_message {
     print $message;
     choose(
         [ 'Press ENTER to continue' ],
-        { %{$sf->{i}{lyt_stop}}, prompt => '' }
+        { %{$sf->{i}{lyt_m}}, prompt => '' }
     );
 }
 
