@@ -6,12 +6,12 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.060_01';
+our $VERSION = '1.060_03';
 
 use File::Basename qw( basename );
 use List::Util     qw( none any );
 
-use Term::Choose       qw();
+use Term::Choose       qw( choose );
 use Term::Choose::Util qw( choose_a_number );
 use Term::Form         qw();
 use Term::TablePrint   qw( print_table );
@@ -37,9 +37,9 @@ sub delete_table {
     my $sql = {};
     my $prompt = '"' . basename( $data->{db} ) . '"' . "\n" . 'Drop table';
     # Choose
-    my $table = $lyt_3->choose(
+    my $table = $lyt_3->choose( #
         [ undef, map { "- $_" } @{$data->{user_tbls}} ],
-        { undef => $sf->{i}{_back}, prompt => $prompt }
+        { prompt => $prompt }
     );
     if ( ! defined $table || ! length $table ) {
         return;
@@ -51,14 +51,14 @@ sub delete_table {
     my $all_arrayref = $sth->fetchall_arrayref;
     my $row_count = @$all_arrayref;
     unshift @$all_arrayref, $sth->{NAME};
-    my $prompt_pt = 'The table to be deleted  -  press enter to continue.';
+    my $prompt_pt = "ENTER to continue\n$sql->{table}:";
     print_table( $all_arrayref, { %{$sf->{o}{table}}, prompt => $prompt_pt, max_rows => 0, table_expand => 0 } );
-    $prompt = sprintf 'Drop table %s (%d %s)?', $sql->{table}, $row_count, $row_count == 1 ? 'row' : 'rows';
-    $ax->print_sql( $sql, [ 'Drop_table' ] );
+    $prompt = sprintf 'DROP TABLE %s  (%d %s)', $sql->{table}, $row_count, $row_count == 1 ? 'row' : 'rows';
+    $prompt .= "\n\nCONFIRM:";
     # Choose
-    my $choice = $lyt_3->choose(
+    my $choice = choose( #
         [ undef, 'YES' ],
-        { prompt => $prompt, undef => 'NO', layout => 1, clear_screen => 0 }
+        { %{$sf->{i}{lyt_m}}, prompt => $prompt, undef => 'NO' }
     );
     if ( defined $choice && $choice eq 'YES' ) {
         $dbh->do( "DROP TABLE $sql->{table}" ) or die "DROP TABLE $sql->{table} failed!";
@@ -72,7 +72,6 @@ sub delete_table {
 
 sub __table_name {
     my ( $sf, $sql, $dbh, $sql_typeS, $data ) = @_;
-    my $lyt_h = Term::Choose->new( $sf->{i}{lyt_stmt_h} );
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
     my $table;
     my $c = 0;
@@ -92,7 +91,10 @@ sub __table_name {
         }
         $ax->print_sql( $sql, $sql_typeS );
         my $prompt = "Table $sql->{table} already exists.";
-        my $choice = $lyt_h->choose( [ undef, 'New name' ], { prompt => $prompt, undef => 'BACK', layout => 3, justify => 0 } );
+        my $choice = choose(
+            [ undef, 'New name' ],
+            { %{$sf->{i}{lyt_stmt_h}}, prompt => $prompt, undef => 'BACK', layout => 3, justify => 0 }
+        );
         if ( ! defined $choice ) {
             return;
         }
@@ -102,13 +104,12 @@ sub __table_name {
 sub create_new_table {
     my ( $sf, $dbh, $data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
-    my $lyt_h = Term::Choose->new( $sf->{i}{lyt_stmt_h} );
     my $sql = {};
     $ax->reset_sql( $sql ); #
-    my @cu_keys = ( qw/create_plain create_copy create_file settings/ );
-    my %cu = ( create_plain  => '- plain',
-               create_copy   => '- CopyPaste',
-               create_file   => '- from File',
+    my @cu_keys = ( qw/create_table_plain create_table_form_copy create_table_form_file settings/ );
+    my %cu = ( create_table_plain  => '- plain',
+               create_table_form_copy   => '- CopyPaste',
+               create_table_form_file   => '- from File',
                settings      => '  Settings'
     );
     my $old_idx = 0;
@@ -118,16 +119,15 @@ sub create_new_table {
         my $choices = [ undef, @cu{@cu_keys} ];
         my $prompt = 'DB: "' . basename( $data->{db} ) . '"' . "\n" . 'Create table';
         # Choose
-        my $idx = $lyt_h->choose(
+        my $idx = choose(
             $choices,
-            { %{$sf->{i}{lyt_stmt_v}}, index => 1, default => $old_idx,
-            undef => '  ' . $sf->{i}{back}, prompt => $prompt, clear_screen => 1 }
+            { %{$sf->{i}{lyt_3}}, index => 1, default => $old_idx, prompt => $prompt }
         );
         if ( ! defined $idx || ! defined $choices->[$idx] ) {
             return;
         }
         my $custom = $choices->[$idx];
-        if ( $sf->{o}{G}{menu_sql_memory} ) {
+        if ( $sf->{o}{G}{menu_memory} ) {
             if ( $old_idx == $idx ) {
                 $old_idx = 0;
                 next MENU;
@@ -140,69 +140,69 @@ sub create_new_table {
             next MENU;
         }
         $ax->reset_sql( $sql ); #
-        if ( $custom eq $cu{create_plain} ) {
+        if ( $custom eq $cu{create_table_plain} ) {
             my $ok = $sf->__data_from_plain( $sql, $dbh, $sql_typeS, $data );
             next MENU if ! $ok;
         }
-        elsif ( $custom eq $cu{create_copy} ) { # name
-            push @$sql_typeS, 'Insert';
-            my $tbl_in = App::DBBrowser::Table::Insert->new( $sf->{i}, $sf->{o} );
-            my $ok = $tbl_in->from_copy_and_paste( $sql, $sql_typeS );
-            if ( ! $ok ) {
-                next MENU;
+        else {
+            if ( $custom eq $cu{create_table_form_copy} ) {
+                push @$sql_typeS, 'Insert';
+                my $tbl_in = App::DBBrowser::Table::Insert->new( $sf->{i}, $sf->{o} );
+                my $ok = $tbl_in->from_copy_and_paste( $sql, $sql_typeS );
+                if ( ! $ok ) {
+                    next MENU;
+                }
             }
-        }
-        elsif ( $custom eq $cu{create_file} ) { # name
-            push @$sql_typeS, 'Insert';
-            my $tbl_in = App::DBBrowser::Table::Insert->new( $sf->{i}, $sf->{o} );
-            my $ok = $tbl_in->from_file( $sql, $sql_typeS );
-            if ( ! $ok ) {
-                next MENU;
+            elsif ( $custom eq $cu{create_table_form_file} ) {
+                push @$sql_typeS, 'Insert';
+                my $tbl_in = App::DBBrowser::Table::Insert->new( $sf->{i}, $sf->{o} );
+                my $ok = $tbl_in->from_file( $sql, $sql_typeS );
+                if ( ! $ok ) {
+                    next MENU;
+                }
             }
-        }
-        if ( $sql_typeS->[-1] eq 'Insert' ) {
             my $ok = $sf->__table_name( $sql, $dbh, $sql_typeS, $data );
             if ( ! $ok ) {
                 next MENU;
             }
             # Columns
-            my ( $first_row, $user_input ) = ( 'Use first row', 'User input' );
+            my ( $first_row, $user_input ) = ( '- Use first row', '- User input' );
             $ax->print_sql( $sql, $sql_typeS );
             # Choose
-            my $choice = $lyt_h->choose(
+            my $choice = choose(
                 [ undef, $first_row, $user_input ],
-                { prompt => 'Column names:', undef => '<<', layout => 3, justify => 0 } #
+                { %{$sf->{i}{lyt_stmt_v}}, prompt => 'Column names:' }
             );
             if ( ! defined $choice ) {
                 $sql->{insert_into_args} = [];
                 next MENU;
             }
             if ( $choice eq $first_row ) {
-                $sql->{insert_into_cols} = shift @{$sql->{insert_into_args}};  # not quoted
+                $sql->{insert_into_cols} = shift @{$sql->{insert_into_args}}; # not quoted
             }
             else {
                 my $c = 0;
                 $sql->{insert_into_cols} = [ map { 'c' . ++$c } @{$sql->{insert_into_args}->[0]} ]; # not quoted
             }
+            my $trs = Term::Form->new( 'cols' );
+            $ax->print_sql( $sql, $sql_typeS );
+            # Fill_form
+            my $c = 0;
+            my $form = $trs->fill_form(
+                [ map { [ ++$c, defined $_ ? "$_" : '' ] } @{$sql->{insert_into_cols}} ],
+                { prompt => 'Col names:', auto_up => 2, confirm => '  CONFIRM', back => '  BACK   ' }
+            );
+            if ( ! $form ) {
+                $sql->{insert_into_cols} = [];
+                next MENU;
+            }
+            $sql->{insert_into_cols} = [ map { $_->[1] } @$form ]; # not quoted
         }
-        #### not col by col
-        my $trs = Term::Form->new( 'cols' );
-        $ax->print_sql( $sql, $sql_typeS );
-        # Fill_form
-        my $c = 0;
-        my $form = $trs->fill_form(
-            [ map { [ ++$c, defined $_ ? "$_" : '' ] } @{$sql->{insert_into_cols}} ],
-            { prompt => 'Col names:', auto_up => 2, confirm => '  CONFIRM', back => '  BACK   ' }
-        );
-        if ( ! $form ) {
-            $sql->{insert_into_cols} = [];
-            next MENU;
-        }
-        #####
-        my @cols = ( map { $_->[1] } @$form );
-        die "Column with no name!" if any { ! length } @cols;
-        $sql->{insert_into_cols} = $ax->quote_simple_many( $dbh, \@cols ); #
+        die "Column with no name!" if any { ! length } @{$sql->{insert_into_cols}};
+        my @cols = @{$sql->{insert_into_cols}}; #
+        $sql->{insert_into_cols} = $ax->quote_simple_many( $dbh, $sql->{insert_into_cols} );
         # Datatypes
+        my $trs = Term::Form->new( 'cols' );
         $ax->print_sql( $sql, $sql_typeS );
         # Fill_form
         my $col_name_and_type = $trs->fill_form( # look
@@ -219,9 +219,9 @@ sub create_new_table {
         # Create table
         $ax->print_sql( $sql, $sql_typeS );
         # Choose
-        my $create_table_ok = $lyt_h->choose(
+        my $create_table_ok = choose(
             [ undef, 'YES' ],
-            { prompt => "Create table $qt_table?", undef => 'NO', index => 1, clear_screen => 0 }
+            { %{$sf->{i}{lyt_m}}, prompt => "Create table $qt_table?", undef => 'NO', index => 1 }
         );
         if ( ! defined $create_table_ok || ! $create_table_ok ) {
             next MENU;
@@ -252,8 +252,8 @@ sub __data_from_plain {
     }
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
     $ax->print_sql( $sql, $sql_typeS );
-    my $col_count = choose_a_number( 3, { small_on_top => 1, confirm => 'Confirm', back => 'Back',
-                                            name => 'Number of columns:', clear_screen => 0 } );
+    my $col_count = choose_a_number( 3, { small_on_top => 1, confirm => 'Confirm', mouse => $sf->{o}{table}{mouse},
+                                          back => 'Back', name => 'Number of columns:', clear_screen => 0 } );
     if ( ! $col_count ) {
         return;
     }
@@ -262,12 +262,12 @@ sub __data_from_plain {
     my $trs = Term::Form->new();
     my $col_names = $trs->fill_form(
         [ map { [ $_, ] } 1 .. $col_count ],
-        { info => $info, confirm => 'OK', back => '<<' }
+        { info => $info, confirm => 'OK', back => '<<', auto_up => 2 }
     );
     if ( ! defined $col_names ) {
         return;
     }
-    $sql->{insert_into_cols} = [ map { $_->[1] } @$col_names ]; # insert_into_cos # not quoted
+    $sql->{insert_into_cols} = [ map { $_->[1] } @$col_names ]; # not quoted
     $ax->print_sql( $sql, $sql_typeS );
     return 1;
 }
