@@ -36,29 +36,29 @@ sub env_variables {
 sub read_arguments {
     my ( $sf ) = @_;
     return [
-        { name => 'host', prompt => "Host",     keep_secret => 0 },
-        { name => 'port', prompt => "Port",     keep_secret => 0 },
-        { name => 'user', prompt => "User",     keep_secret => 0 },
-        { name => 'pass', prompt => "Password", keep_secret => 1 },
+        { name => 'host', prompt => "Host",     secret => 0 },
+        { name => 'port', prompt => "Port",     secret => 0 },
+        { name => 'user', prompt => "User",     secret => 0 },
+        { name => 'pass', prompt => "Password", secret => 1 },
     ];
 }
 
 
 sub set_attributes {
     my ( $sf ) = @_;
-    return 'mysql', [
-        { name => 'mysql_enable_utf8',        default_index => 1, avail_values => [ 0, 1 ] },
-        { name => 'mysql_enable_utf8mb4',     default_index => 0, avail_values => [ 0, 1 ] }, ##
-        { name => 'mysql_bind_type_guessing', default_index => 1, avail_values => [ 0, 1 ] },
+    return [
+        { name => 'mysql_enable_utf8',        default => 1, values => [ 0, 1 ] },
+        { name => 'mysql_enable_utf8mb4',     default => 0, values => [ 0, 1 ] }, ##
+        { name => 'mysql_bind_type_guessing', default => 1, values => [ 0, 1 ] },
     ];
 }
 
 
 sub db_handle {
-    my ( $sf, $db, $connect_parameter ) = @_;
-    my $obj_db_cred = App::DBBrowser::Credentials->new( { connect_parameter => $connect_parameter } );
+    my ( $sf, $db, $parameter ) = @_;
+    my $obj_db_cred = App::DBBrowser::Credentials->new( { parameter => $parameter } );
     my $dsn;
-    if ( ! ( $connect_parameter->{use_env_var}{DBI_DSN} &&  exists $ENV{DBI_DSN} ) ) {
+    if ( ! $parameter->{use_env_var}{DBI_DSN} || ! exists $ENV{DBI_DSN} ) {
         my $host = $obj_db_cred->get_login( 'host' );
         my $port = $obj_db_cred->get_login( 'port' );
         $dsn = "dbi:$sf->{driver}:dbname=$db";
@@ -72,14 +72,14 @@ sub db_handle {
         RaiseError => 1,
         AutoCommit => 1,
         ShowErrorStatement => 1,
-        %{$connect_parameter->{set_attr}},
+        %{$parameter->{attributes}},
     } ) or die DBI->errstr;
     return $dbh;
 }
 
 
 sub databases {
-    my ( $sf, $connect_parameter ) = @_;
+    my ( $sf, $parameter ) = @_;
     return \@ARGV if @ARGV;
     my @regex_system_db = ( '^mysql$', '^information_schema$', '^performance_schema$' );
     my $stmt = "SELECT schema_name FROM information_schema.schemata";
@@ -90,7 +90,7 @@ sub databases {
     my $info_database = 'information_schema';
     print $sf->{clear_screen};
     print "DB: $info_database\n";
-    my $dbh = $sf->db_handle( $info_database, $connect_parameter );
+    my $dbh = $sf->db_handle( $info_database, $parameter );
     my $databases = $dbh->selectcol_arrayref( $stmt, {}, $sf->{add_metadata} ? () : @regex_system_db );
     $dbh->disconnect(); #
     if ( $sf->{add_metadata} ) {
@@ -118,52 +118,6 @@ sub databases {
 #}
 
 
-#sub sql_regexp {
-#    my ( $sf, $quote_col, $do_not_match_regexp, $case_sensitive ) = @_;
-#    if ( $do_not_match_regexp ) {
-#        return ' '. $quote_col . ' NOT REGEXP ?'        if ! $case_sensitive;
-#        return ' '. $quote_col . ' NOT REGEXP BINARY ?' if   $case_sensitive;
-#    }
-#    else {
-#        return ' '. $quote_col . ' REGEXP ?'            if ! $case_sensitive;
-#        return ' '. $quote_col . ' REGEXP BINARY ?'     if   $case_sensitive;
-#    }
-#}
-
-#sub concatenate {
-#    my ( $sf, $arg ) = @_;
-#    return 'concat(' . join( ',', @$arg ) . ')';
-#}
-
-
-# scalar functions
-
-#sub epoch_to_datetime {
-#    my ( $sf, $col, $interval ) = @_;
-#    # mysql: FROM_UNIXTIME doesn't work with negative timestamps
-#    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d %H:%i:%s')";
-#}
-
-#sub epoch_to_date {
-#    my ( $sf, $col, $interval ) = @_;
-#    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d')";
-#}
-
-#sub truncate {
-#    my ( $sf, $col, $precision ) = @_;
-#    return "TRUNCATE($col,$precision)";
-#}
-
-#sub bit_length {
-#    my ( $sf, $col ) = @_;
-#    return "BIT_LENGTH($col)";
-#}
-
-#sub char_length {
-#    my ( $sf, $col ) = @_;
-#    return "CHAR_LENGTH($col)";
-#}
-
 
 
 
