@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.060_01';
+our $VERSION = '1.060_03';
 
 use File::Basename        qw( fileparse );
 use File::Spec::Functions qw( catfile );
@@ -14,7 +14,7 @@ use FindBin               qw( $RealBin $RealScript );
 #use Pod::Usage            qw( pod2usage );  # "require"-d
 
 use Term::Choose       qw( choose );
-use Term::Choose::Util qw( insert_sep print_hash choose_a_number choose_a_subset settings_menu choose_a_dir );
+use Term::Choose::Util qw( insert_sep print_hash choose_a_number choose_a_subset settings_menu choose_a_dir choose_dirs );
 use Term::Form         qw();
 
 use App::DBBrowser::Auxil;
@@ -33,9 +33,7 @@ sub defaults {
     my $defaults = {
         G => {
             plugins              => [ 'SQLite', 'mysql', 'Pg' ],
-            menus_config_memory  => 0,
-            menu_sql_memory      => 0,
-            menus_db_memory      => 0,
+            menu_memory          => 0,
             thsd_sep             => ',',
             max_rows             => 50_000,
             meta                 => 0,
@@ -43,9 +41,9 @@ sub defaults {
             operators            => [ "REGEXP", "REGEXP_i", " = ", " != ", " < ", " > ", "IS NULL", "IS NOT NULL" ],
             parentheses_w        => 0,
             parentheses_h        => 0,
-#            dequote              => 1,
             quote_identifiers    => 1,
             qualified_table_name => 0,
+            dirs_sqlite           => [ $sf->{i}{home_dir} ],
         },
         table => {
             table_expand         => 1,
@@ -155,7 +153,7 @@ sub config_insert {
                     return
                 }
             }
-            if ( $sf->{o}{G}{menus_config_memory} ) {
+            if ( $sf->{o}{G}{menu_memory} ) {
                 if ( $old_idx == $idx ) {
                     $old_idx = 0;
                     next OPTION_INSERT;
@@ -176,7 +174,7 @@ sub config_insert {
                 redo GROUP_INSERT;
             }
             my $section  = $sub_menu_insert->[$idx - @pre]{section};
-            my $opt_type = 'o';
+            #my $opt_type = 'o';
             my $no_yes   = [ 'NO', 'YES' ];
 #            if ( $option eq 'input_modes' ) {
 #                    my $available = [ 'Cols', 'Rows', 'Multi-row', 'File' ];
@@ -264,8 +262,9 @@ sub __menus {
             { name => 'config_insert',   text => "- Insert" },
         ],
         config_database => [
-            { name => '_db_defaults', text => "- DB Settings"                },
-            { name => 'plugins',      text => "- DB Plugins", section => 'G' },
+            { name => '_db_defaults', text => "- DB Settings"                        },
+            { name => 'plugins',      text => "- DB Plugins",         section => 'G' },
+            { name => 'dirs_sqlite',  text => "- Sqlite directories", section => 'G' }, # docu
         ],
         config_menu => [
             { name => '_menu_memory',  text => "- Menu Memory", section => 'G' },
@@ -328,7 +327,7 @@ sub set_options {
                     exit();
                 }
             }
-            if ( $sf->{o}{G}{menus_config_memory} ) {
+            if ( $sf->{o}{G}{menu_memory} ) {
                 if ( $old_idx == $idx ) {
                     $old_idx = 0;
                     next OPTION;
@@ -387,10 +386,14 @@ sub set_options {
                 $obj_o_db->database_setting();
                 next OPTION;
             }
-            my $opt_type = 'o';
+            #my $opt_type = 'o';
             my $section  = $menu->[$idx - @pre]{section};
             my $no_yes   = [ 'NO', 'YES' ];
-            if ( $option eq 'plugins' ) {
+            if ( $option eq 'dirs_sqlite' ) {
+                # choose first a plugin and only if plugin SQLite then
+                $sf->__choose_dirs_wrap( $section, $option );
+            }
+            elsif ( $option eq 'plugins' ) {
                 my %installed_driver;
                 for my $dir ( @INC ) {
                     my $glob_pattern = catfile $dir, 'App', 'DBBrowser', 'DB', '*.pm';
@@ -464,7 +467,12 @@ sub set_options {
                 $sf->__settings_menu_wrap( $section, $sub_menu );
             }
             elsif ( $option eq 'operators' ) {
-                my $available = $sf->{i}{avail_operators};
+                my $available =[
+                    "REGEXP", "REGEXP_i", "NOT REGEXP", "NOT REGEXP_i", "LIKE", "NOT LIKE", "IS NULL", "IS NOT NULL",
+                    "IN", "NOT IN", "BETWEEN", "NOT BETWEEN", " = ", " != ", " <> ", " < ", " > ", " >= ", " <= ",
+                    " = col", " != col", " <> col", " < col", " > col", " >= col", " <= col",
+                    "LIKE %col%", "NOT LIKE %col%",  "LIKE col%", "NOT LIKE col%", "LIKE %col", "NOT LIKE %col" ],
+                    # "LIKE col", "NOT LIKE col"
                 my $prompt = 'Choose operators:';
                 $sf->__choose_a_subset_wrap( $section, $option, $available, $prompt );
             }
@@ -485,9 +493,7 @@ sub set_options {
             elsif ( $option eq '_menu_memory' ) {
                 my $prompt = 'Choose: ';
                 my $sub_menu = [
-                    [ 'menus_config_memory', "- Config Menus", [ 'Simple', 'Memory' ] ],
-                    [ 'menu_sql_memory',     "- SQL    Menu",  [ 'Simple', 'Memory' ] ],
-                    [ 'menus_db_memory',     "- DB     Menus", [ 'Simple', 'Memory' ] ],
+                    [ 'menu_memory',     "- Menu memory", [ 'NO', 'YES' ] ],
                 ];
                 $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
             }
@@ -506,7 +512,7 @@ sub set_options {
 
 sub __settings_menu_wrap {
     my ( $sf, $section, $sub_menu, $prompt ) = @_;
-    my $changed = settings_menu( $sub_menu, $sf->{o}{$section}, { prompt => $prompt } );
+    my $changed = settings_menu( $sub_menu, $sf->{o}{$section}, { prompt => $prompt, mouse => $sf->{o}{table}{mouse} } );
     return if ! $changed;
     $sf->{i}{write_config}++;
 }
@@ -515,7 +521,7 @@ sub __choose_a_subset_wrap {
     my ( $sf, $section, $option, $available, $prompt ) = @_;
     my $current = $sf->{o}{$section}{$option};
     # Choose_list
-    my $list = choose_a_subset( $available, { prompt => $prompt, current => $current, index => 0 } );
+    my $list = choose_a_subset( $available, { prompt => $prompt, current => $current, index => 0, mouse => $sf->{o}{table}{mouse} } );
     return if ! defined $list;
     return if ! @$list;
     $sf->{o}{$section}{$option} = $list;
@@ -528,7 +534,7 @@ sub __choose_a_number_wrap {
     my $current = $sf->{o}{$section}{$option};
     $current = insert_sep( $current, $sf->{o}{G}{thsd_sep} );
     # Choose_a_number
-    my $choice = choose_a_number( $digits, { name => $prompt, current => $current } );
+    my $choice = choose_a_number( $digits, { name => $prompt, current => $current, mouse => $sf->{o}{table}{mouse} } );
     return if ! defined $choice;
     $sf->{o}{$section}{$option} = $choice eq '--' ? undef : $choice;
     $sf->{i}{write_config}++;
@@ -567,10 +573,21 @@ sub __choose_a_dir_wrap {
     return;
 }
 
+sub __choose_dirs_wrap {
+    my ( $sf, $section, $option ) = @_;
+    my $current = $sf->{o}{$section}{$option};
+    # Choose_dirs
+    my $dirs = choose_dirs( { mouse => $sf->{o}{table}{mouse}, current => $current } );
+    return if ! defined $dirs;
+    return if ! @$dirs;
+    $sf->{o}{$section}{$option} = $dirs;
+    $sf->{i}{write_config}++;
+    return;
+}
+
 
 sub __write_config_files {
     my ( $sf ) = @_;
-    my $fmt = $sf->{i}{conf_file_fmt};
     my $tmp = {};
     for my $section ( keys %{$sf->{o}} ) {
         for my $option ( keys %{$sf->{o}{$section}} ) {
@@ -578,18 +595,17 @@ sub __write_config_files {
         }
     }
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
-    my $file_name = $sf->{i}{config_generic};
-    $ax->write_json( sprintf( $fmt, $file_name ), $tmp  );
+    my $file_name = $sf->{i}{file_settings};
+    $ax->write_json( $file_name, $tmp  );
 }
 
 sub read_config_files {
     my ( $sf ) = @_;
     my $o = $sf->defaults();
-    my $fmt = $sf->{i}{conf_file_fmt};
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
-    my $file =  sprintf( $fmt, $sf->{i}{config_generic} );
-    if ( -f $file && -s $file ) {
-        my $tmp = $ax->read_json( $file );
+    my $file_name = $sf->{i}{file_settings};
+    if ( -f $file_name && -s $file_name ) {
+        my $tmp = $ax->read_json( $file_name );
         for my $section ( keys %$tmp ) {
             for my $option ( keys %{$tmp->{$section}} ) {
                 $o->{$section}{$option} = $tmp->{$section}{$option} if exists $o->{$section}{$option};
