@@ -6,11 +6,13 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.060_01';
+our $VERSION = '1.060_03';
 
 use Clone           qw( clone );
 use List::MoreUtils qw( first_index );
-use Term::Choose    qw();
+
+use Term::Choose       qw( choose );
+use Term::Choose::Util qw( choose_a_number );
 
 use App::DBBrowser::Auxil;
 use App::DBBrowser::DB;
@@ -25,7 +27,6 @@ sub new {
 sub col_function {
     my ( $sf, $dbh, $sql, $backup_sql, $sql_type ) = @_;
     my $ax  = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o} );
-    my $stmt_h = Term::Choose->new( $sf->{i}{lyt_stmt_h} );
     my @functions = ( qw( Epoch_to_Date Bit_Length Truncate Char_Length Epoch_to_DateTime ) );
     my $stmt_key = '';
     if ( $sql->{select_type} eq '*' ) {
@@ -64,9 +65,9 @@ sub col_function {
         my $choices = [ @pre, map( "- $_", @cols ) ];
         $ax->print_sql( $sql, [ $sql_type ] );
         # Choose
-        my $idx = $stmt_h->choose(
+        my $idx = choose(
             $choices,
-            { %{$sf->{i}{lyt_stmt_v}}, index => 1, default => $default, prompt => 'Choose:' }
+            { %{$sf->{i}{lyt_stmt_v}}, index => 1, default => $default }
         );
         if ( ! defined $idx || ! defined $choices->[$idx] ) {
             $sql = clone( $backup_sql );
@@ -103,7 +104,7 @@ sub col_function {
         }
         $ax->print_sql( $sql, [ $sql_type ] );
         # Choose
-        my $function = $stmt_h->choose(
+        my $function = choose(
             [ undef, map( "  $_", @functions ) ],
             { %{$sf->{i}{lyt_stmt_v}} }
         );
@@ -135,7 +136,6 @@ sub col_function {
 sub __prepare_col_func {
     my ( $sf, $func, $qt_col ) = @_;
     my $obj_db = App::DBBrowser::DB->new( $sf->{i}, $sf->{o} );
-    my $obj_ch = Term::Choose->new();
     my $quote_f;
     if ( $func =~ /^Epoch_to_Date(?:Time)?\z/ ) {
         my $prompt = $func eq 'Epoch_to_Date' ? 'DATE' : 'DATETIME';
@@ -146,7 +146,7 @@ sub __prepare_col_func {
             '  **********               Second' );
         my $choices = [ undef, $microseconds, $milliseconds, $seconds ];
         # Choose
-        my $interval = $obj_ch->choose(
+        my $interval = choose(
             $choices,
             { %{$sf->{i}{lyt_stmt_v}}, prompt => $prompt }
         );
@@ -161,12 +161,10 @@ sub __prepare_col_func {
         }
     }
     elsif ( $func eq 'Truncate' ) {
-        my $prompt = "TRUNC $qt_col\nDecimal places:";
-        my $choices = [ undef, 0 .. 9 ];
-        # Choose
-        my $precision = $obj_ch->choose(
-            $choices,
-            { %{$sf->{i}{lyt_stmt_h}}, prompt => $prompt }
+        my $info = "TRUNC $qt_col";
+        my $name = "Decimal places:";
+        my $precision = choose_a_number( 2,
+            { info => $info, name => $name, small_on_top => 1, mouse => $sf->{o}{table}{mouse}, clear_screen => 0 }
         );
         return if ! defined $precision;
         $quote_f = $obj_db->truncate( $qt_col, $precision );
